pub struct TiRexModel { /* private fields */ }Implementations
Sourceimpl TiRexModel
impl TiRexModel
pub fn load(gguf_path: &Path, config: TiRexConfig) -> Result<Self>
Sourcepub fn forecast(
&self,
context: &[f32],
prediction_length: usize,
) -> Result<(Vec<Vec<f32>>, Vec<f32>)>
pub fn forecast( &self, context: &[f32], prediction_length: usize, ) -> Result<(Vec<Vec<f32>>, Vec<f32>)>
Forecast quantiles and the median for a single time series.
Returns (quantiles, median) where:
quantiles:[prediction_length, num_quantiles]in the config’s quantile ordermedian:[prediction_length](the 0.5 quantile row, for convenience — despite the name this function and callers used historically, it is the median, not a distinct mean statistic)